@@ -1,15 +1,18 @@
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 // SPDX-FileCopyrightText: 2020 Tomaz Canabrava <tcanabrava@kde.org>
 
-#ifndef MOBILEPOWER_H
-#define MOBILEPOWER_H
+#pragma once
+
+#include "batterymodel.h"
 
 #include <KQuickAddons/ConfigModule>
+#include <KSharedConfig>
 #include <memory>
 
 class MobilePower : public KQuickAddons::ConfigModule
 {
     Q_OBJECT
+    Q_PROPERTY(BatteryModel *batteries READ batteries CONSTANT)
     Q_PROPERTY(int dimScreenIdx READ dimScreenIdx WRITE setDimScreenIdx NOTIFY dimScreenIdxChanged)
     Q_PROPERTY(int screenOffIdx READ screenOffIdx WRITE setScreenOffIdx NOTIFY screenOffIdxChanged)
     Q_PROPERTY(int suspendSessionIdx READ suspendSessionIdx WRITE setSuspendSessionIdx NOTIFY suspendSessionIdxChanged)
@@ -27,6 +30,8 @@ public:
     int screenOffIdx();
     int suspendSessionIdx();
 
+    BatteryModel *batteries();
+
     Q_SIGNAL void dimScreenIdxChanged();
     Q_SIGNAL void screenOffIdxChanged();
     Q_SIGNAL void suspendSessionIdxChanged();
@@ -37,8 +42,10 @@ public:
     void save() override;
 
 private:
-    struct Private;
-    std::unique_ptr<Private> d;
-};
+    BatteryModel *m_batteries;
+    KSharedConfig::Ptr m_profilesConfig;
 
-#endif
+    qreal m_suspendSessionTime;
+    qreal m_dimScreenTime;
+    qreal m_screenOffTime;
+};
