@@ -1,9 +1,9 @@
-/***************************************************************************
- *   SPDX-FileCopyrightText: 2014 Kai Uwe Broulik <kde@privat.broulik.de>            *
- *   SPDX-FileCopyrightText: 2014 Martin Klapetek <mklapetek@kde.org>               *
- *                                                                         *
- *   SPDX-License-Identifier: GPL-2.0-or-later
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2014 Kai Uwe Broulik <kde@privat.broulik.de>
+    SPDX-FileCopyrightText: 2014 Martin Klapetek <mklapetek@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "timezonemodel.h"
 #include "timezonesi18n.h"
@@ -200,8 +200,13 @@ void TimeZoneModel::selectLocalTimeZone()
 
 QHash<int, QByteArray> TimeZoneModel::roleNames() const
 {
-    return QHash<int, QByteArray>(
-        {{TimeZoneIdRole, "timeZoneId"}, {RegionRole, "region"}, {CityRole, "city"}, {CommentRole, "comment"}, {CheckedRole, "checked"}});
+    return QHash<int, QByteArray>({
+        {TimeZoneIdRole, "timeZoneId"},
+        {RegionRole, "region"},
+        {CityRole, "city"},
+        {CommentRole, "comment"},
+        {CheckedRole, "checked"},
+    });
 }
 
 void TimeZoneModel::sortTimeZones()
