@@ -1,9 +1,9 @@
-/***************************************************************************
- *   SPDX-FileCopyrightText: 2014 Kai Uwe Broulik <kde@privat.broulik.de>            *
- *   SPDX-FileCopyrightText: 2014 Martin Klapetek <mklapetek@kde.org>               *
- *                                                                         *
- *   SPDX-License-Identifier: GPL-2.0-or-later
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2014 Kai Uwe Broulik <kde@privat.broulik.de>
+    SPDX-FileCopyrightText: 2014 Martin Klapetek <mklapetek@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef TIMEZONEMODEL_H
 #define TIMEZONEMODEL_H
@@ -45,7 +45,13 @@ public:
     explicit TimeZoneModel(QObject *parent = nullptr);
     ~TimeZoneModel() override;
 
-    enum Roles { TimeZoneIdRole = Qt::UserRole + 1, RegionRole, CityRole, CommentRole, CheckedRole };
+    enum Roles {
+        TimeZoneIdRole = Qt::UserRole + 1,
+        RegionRole,
+        CityRole,
+        CommentRole,
+        CheckedRole,
+    };
 
     int rowCount(const QModelIndex &parent) const override;
     QVariant data(const QModelIndex &index, int role) const override;
