@@ -27,9 +27,6 @@ class VirtualKeyboard : public KQuickAddons::ConfigModule
     Q_PROPERTY(bool soundFeedback MEMBER m_soundFeedback WRITE setSoundFeedback NOTIFY soundFeedbackChanged)
     Q_PROPERTY(bool vibrateFeedback MEMBER m_vibrateFeedback WRITE setVibrateFeedback NOTIFY vibrateFeedbackChanged)
 
-    Q_PROPERTY(QString theme MEMBER m_theme WRITE setTheme NOTIFY themeChanged)
-    Q_PROPERTY(QStringList availableThemes MEMBER m_availableThemes NOTIFY availableThemesChanged)
-
 public:
     VirtualKeyboard(QObject *parent, const QVariantList &args);
 
@@ -42,9 +39,6 @@ public:
     void setSoundFeedback(bool enabled);
     void setVibrateFeedback(bool enabled);
 
-    void setTheme(QString theme);
-    QStringList availableThemes();
-
 Q_SIGNALS:
     void spellCheckChanged();
     void autoCapitalizeChanged();
@@ -53,8 +47,6 @@ Q_SIGNALS:
     void fullStopOnDoubleSpaceChanged();
     void soundFeedbackChanged();
     void vibrateFeedbackChanged();
-    void themeChanged();
-    void availableThemesChanged();
 
 private:
     GSettingsItem *m_gsettings;
@@ -70,10 +62,6 @@ private:
     // feedback
     bool m_soundFeedback;
     bool m_vibrateFeedback;
-
-    // theme
-    QString m_theme;
-    QStringList m_availableThemes;
 };
 
 #endif
